@@ -53,9 +53,6 @@ FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.Disassociate
 # 修改账号权限失败。
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
-# 消息队列操作失败。
-FAILEDOPERATION_MSGQUEUEOPERATIONFAILED = 'FailedOperation.MsgQueueOperationFailed'
-
 # 请求后端接口失败。
 FAILEDOPERATION_OSSOPERATIONFAILED = 'FailedOperation.OssOperationFailed'
 
@@ -71,6 +68,9 @@ FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 # 标签键值校验或鉴权失败。
 FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 
+# 标签配额不足。
+FAILEDOPERATION_TAGQUOTAEXCEEDLIMIT = 'FailedOperation.TagQuotaExceedLimit'
+
 # 实例安全组信息更新失败。
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
@@ -179,6 +179,9 @@ INTERNALERROR_OPERATEDATABASEFAILED = 'InternalError.OperateDatabaseFailed'
 # 操作读DB数据错误。
 INTERNALERROR_QUERYDATABASEFAILED = 'InternalError.QueryDatabaseFailed'
 
+# 查询订单信息失败。
+INTERNALERROR_QUERYORDERFAILED = 'InternalError.QueryOrderFailed'
+
 # 查询价格失败。
 INTERNALERROR_QUERYPRICEFAILED = 'InternalError.QueryPriceFailed'
 
@@ -212,6 +215,9 @@ INVALIDPARAMETER_CHARACTERERROR = 'InvalidParameter.CharacterError'
 # 入参校验失败。
 INVALIDPARAMETER_CHECKPARAMNOTPASS = 'InvalidParameter.CheckParamNotPass'
 
+# 未指定需要查询的订单ID。
+INVALIDPARAMETER_DEALNAMENOTGIVEN = 'InvalidParameter.DealNameNotGiven'
+
 # 找不到指定的流程信息。
 INVALIDPARAMETER_FLOWNOTFOUND = 'InvalidParameter.FlowNotFound'
 
@@ -293,6 +299,9 @@ INVALIDPARAMETERVALUE_ILLEGALZONE = 'InvalidParameterValue.IllegalZone'
 # 非法的实例名称。
 INVALIDPARAMETERVALUE_INSTANCENAMEILLEGAL = 'InvalidParameterValue.InstanceNameIllegal'
 
+# 参数验证错误。
+INVALIDPARAMETERVALUE_INVALIDPARAMETERVALUEERROR = 'InvalidParameterValue.InvalidParameterValueError'
+
 # 分片不存在。
 INVALIDPARAMETERVALUE_SHARDNOTEXIST = 'InvalidParameterValue.ShardNotExist'
 
@@ -308,9 +317,15 @@ LIMITEXCEEDED_TOOFREQUENTLYCALLED = 'LimitExceeded.TooFrequentlyCalled'
 # 临时实例已经存在。
 RESOURCEINUSE_TEMPINSTANCEEXIST = 'ResourceInUse.TempInstanceExist'
 
+# 资源不足。
+RESOURCEINSUFFICIENT = 'ResourceInsufficient'
+
 # 指定的账号不存在。
 RESOURCENOTFOUND_ACCOUNTDOESNOTEXIST = 'ResourceNotFound.AccountDoesNotExist'
 
+# 实例不存在。
+RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
+
 # 找不到指定的数据库实例。
 RESOURCENOTFOUND_NOINSTANCEFOUND = 'ResourceNotFound.NoInstanceFound'
 
